@@ -47,6 +47,7 @@ import logging
 import re
 import binascii
 import base64
+import math
 import decimal as python_decimal
 from pyxb.exceptions_ import *
 import pyxb.namespace
@@ -92,7 +93,7 @@ _PrimitiveDatatypes.append(string)
 
 # It is illegal to subclass the bool type in Python, so we subclass
 # int instead.
-@six.unicode_convertible
+@six.python_2_unicode_compatible
 class boolean (basis.simpleTypeDefinition, six.int_type):
     """XMLSchema datatype U{boolean<http://www.w3.org/TR/xmlschema-2/#boolean>}."""
     _XsdBaseType = anySimpleType
@@ -183,26 +184,29 @@ class decimal (basis.simpleTypeDefinition, python_decimal.Decimal, basis._Repres
 
 _PrimitiveDatatypes.append(decimal)
 
-class float (basis.simpleTypeDefinition, six.float_type):
-    """XMLSchema datatype U{float<http://www.w3.org/TR/xmlschema-2/#float>}."""
+class _fp (basis.simpleTypeDefinition, six.float_type):
     _XsdBaseType = anySimpleType
-    _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('float')
 
     @classmethod
     def XsdLiteral (cls, value):
+        if math.isinf(value):
+            if (0 > value):
+                return '-INF'
+            return 'INF'
+        if math.isnan(value):
+            return 'NaN'
         return '%s' % (value,)
 
+class float (_fp):
+    """XMLSchema datatype U{float<http://www.w3.org/TR/xmlschema-2/#float>}."""
+    _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('float')
+
 _PrimitiveDatatypes.append(float)
 
-class double (basis.simpleTypeDefinition, six.float_type):
+class double (_fp):
     """XMLSchema datatype U{double<http://www.w3.org/TR/xmlschema-2/#double>}."""
-    _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('double')
 
-    @classmethod
-    def XsdLiteral (cls, value):
-        return '%s' % (value,)
-
 _PrimitiveDatatypes.append(double)
 
 import datetime
@@ -354,6 +358,9 @@ class duration (basis.simpleTypeDefinition, datetime.timedelta, basis._Represent
         if 0 < len(time_elts):
             elts.append('T')
             elts.extend(time_elts)
+        if 1 == len(elts):
+            # Value must have zero duration.  Pick something short.
+            elts.append('0D')
         return ''.join(elts)
 
 _PrimitiveDatatypes.append(duration)
@@ -806,7 +813,7 @@ class hexBinary (basis.simpleTypeDefinition, six.binary_type):
 
     @classmethod
     def _ConvertArguments_vx (cls, args, kw):
-        if kw.get('_from_xml', False):
+        if (1 <= len(args)) and kw.get('_from_xml', False):
             xmlt = args[0]
             try:
                 xmld = xmlt.encode('utf-8')
@@ -838,9 +845,10 @@ class base64Binary (basis.simpleTypeDefinition, six.binary_type):
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('base64Binary')
 
-    # base64 is too lenient: it accepts 'ZZZ=' as an encoding of 'e', while
-    # the required XML Schema production requires 'ZQ=='.  Define a regular
-    # expression per section 3.2.16.
+    # base64 is too lenient: it accepts 'ZZZ=' as an encoding of
+    # 'e\x96', while the required XML Schema production requires
+    # 'ZZY='.  Define a regular expression per section 3.2.16.
+
     _B04 = '[AQgw]'
     _B04S = '(%s ?)' % (_B04,)
     _B16 = '[AEIMQUYcgkosw048]'
@@ -851,9 +859,34 @@ class base64Binary (basis.simpleTypeDefinition, six.binary_type):
     __Pattern = '^((' + _B64S + '{4})*((' + _B64S + '{3}' + _B64 + ')|(' + _B64S + '{2}' + _B16S + '=)|(' + _B64S + _B04S + '= ?=)))?$'
     __Lexical_re = re.compile(__Pattern)
 
+    __ValidateLength = None
+
+    @classmethod
+    def XsdValidateLength (cls, length):
+        """Control the maximum encoded size that is checked for XML literal validity.
+
+        Python's base64 module allows some literals that are invalid
+        according to XML rules.  PyXB verifies the validity using a
+        regular expression, which is costly for something that is
+        unlikely to occur.  Use this function to inhibit checks for
+        validity based on the length of the XML literal.
+
+        @param length: C{None} (default) to check all literals,
+        otherwise the maximum length literal that will be checked.
+        Pass C{-1} to disable the validity check.
+
+        @return: the previous validation length
+
+        """
+        rv = cls.__ValidateLength
+        if (length is None) or isinstance(length, six.integer_types):
+            cls.__ValidateLength = length
+            return rv
+        raise TypeError('must provide None or integer length')
+
     @classmethod
     def _ConvertArguments_vx (cls, args, kw):
-        if kw.get('_from_xml', False):
+        if (1 <= len(args)) and kw.get('_from_xml', False):
             xmlt = args[0]
             try:
                 xmld = xmlt.encode('utf-8')
@@ -861,9 +894,10 @@ class base64Binary (basis.simpleTypeDefinition, six.binary_type):
                 args = (arg0,) + args[1:]
             except (TypeError, binascii.Error):
                 raise SimpleTypeValueError(cls, xmlt)
-            # This is what it costs to try to be a validating processor.
-            if cls.__Lexical_re.match(xmlt) is None:
-                raise SimpleTypeValueError(cls, xmlt)
+            if (cls.__ValidateLength is None) or (cls.__ValidateLength >= len(xmlt)):
+                # This is what it costs to try to be a validating processor.
+                if cls.__Lexical_re.match(xmlt) is None:
+                    raise SimpleTypeValueError(cls, xmlt)
         return args
 
     @classmethod
