@@ -1,7 +1,7 @@
 # ./pyxb/bundles/saml20/raw/ecp.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:2fcdef609f6a0a75f54ed59ff0ad0ce2350eb6e6
-# Generated 2014-10-19 06:25:02.409599 by PyXB version 1.2.4 using Python 2.7.3.final.0
+# Generated 2016-09-18 17:34:11.707815 by PyXB version 1.2.5 using Python 2.7.12.final.0
 # Namespace urn:oasis:names:tc:SAML:2.0:profiles:SSO:ecp
 
 from __future__ import unicode_literals
@@ -13,21 +13,24 @@ import pyxb.utils.utility
 import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
-
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:91537446-5782-11e4-8785-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:055590dc-7df0-11e6-9fa4-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.4'
+_PyXBVersion = '1.2.5'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
 
+# A holder for module-level binding classes so we can access them from
+# inside class definitions where property names may conflict.
+_module_typeBindings = pyxb.utils.utility.Object()
+
 # Import bindings for namespaces imported into schema
-import pyxb.bundles.saml20.protocol
+import pyxb.bundles.saml20.assertion
 import pyxb.bundles.wssplat.soap11
 import pyxb.binding.datatypes
-import pyxb.bundles.saml20.assertion
+import pyxb.bundles.saml20.protocol
 
 # NOTE: All namespace declarations are reserved within the binding
 Namespace = pyxb.namespace.NamespaceForURI('urn:oasis:names:tc:SAML:2.0:profiles:SSO:ecp', create_if_missing=True)
@@ -89,20 +92,20 @@ class RequestType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'RequestType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 30, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 30, 4)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {urn:oasis:names:tc:SAML:2.0:assertion}Issuer uses Python identifier Issuer
-    __Issuer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(_Namespace_saml, 'Issuer'), 'Issuer', '__urnoasisnamestcSAML2_0profilesSSOecp_RequestType_urnoasisnamestcSAML2_0assertionIssuer', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/assertion.xsd', 54, 4), )
+    __Issuer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(_Namespace_saml, 'Issuer'), 'Issuer', '__urnoasisnamestcSAML2_0profilesSSOecp_RequestType_urnoasisnamestcSAML2_0assertionIssuer', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/assertion.xsd', 54, 4), )
 
     
     Issuer = property(__Issuer.value, __Issuer.set, None, None)
 
     
     # Element {urn:oasis:names:tc:SAML:2.0:protocol}IDPList uses Python identifier IDPList
-    __IDPList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(_Namespace_samlp, 'IDPList'), 'IDPList', '__urnoasisnamestcSAML2_0profilesSSOecp_RequestType_urnoasisnamestcSAML2_0protocolIDPList', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/protocol.xsd', 188, 4), )
+    __IDPList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(_Namespace_samlp, 'IDPList'), 'IDPList', '__urnoasisnamestcSAML2_0profilesSSOecp_RequestType_urnoasisnamestcSAML2_0protocolIDPList', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/protocol.xsd', 188, 4), )
 
     
     IDPList = property(__IDPList.value, __IDPList.set, None, None)
@@ -110,32 +113,32 @@ class RequestType (pyxb.binding.basis.complexTypeDefinition):
     
     # Attribute {http://schemas.xmlsoap.org/soap/envelope/}mustUnderstand uses Python identifier mustUnderstand
     __mustUnderstand = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(_Namespace_S, 'mustUnderstand'), 'mustUnderstand', '__urnoasisnamestcSAML2_0profilesSSOecp_RequestType_httpschemas_xmlsoap_orgsoapenvelopemustUnderstand', pyxb.bundles.wssplat.soap11.STD_ANON, required=True)
-    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/soap11.xsd', 75, 2)
-    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 35, 8)
+    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/soap11.xsd', 75, 2)
+    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 35, 8)
     
     mustUnderstand = property(__mustUnderstand.value, __mustUnderstand.set, None, None)
 
     
     # Attribute {http://schemas.xmlsoap.org/soap/envelope/}actor uses Python identifier actor
     __actor = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(_Namespace_S, 'actor'), 'actor', '__urnoasisnamestcSAML2_0profilesSSOecp_RequestType_httpschemas_xmlsoap_orgsoapenvelopeactor', pyxb.binding.datatypes.anyURI, required=True)
-    __actor._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/soap11.xsd', 82, 2)
-    __actor._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 36, 8)
+    __actor._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/soap11.xsd', 82, 2)
+    __actor._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 36, 8)
     
     actor = property(__actor.value, __actor.set, None, None)
 
     
     # Attribute ProviderName uses Python identifier ProviderName
     __ProviderName = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'ProviderName'), 'ProviderName', '__urnoasisnamestcSAML2_0profilesSSOecp_RequestType_ProviderName', pyxb.binding.datatypes.string)
-    __ProviderName._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 37, 8)
-    __ProviderName._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 37, 8)
+    __ProviderName._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 37, 8)
+    __ProviderName._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 37, 8)
     
     ProviderName = property(__ProviderName.value, __ProviderName.set, None, None)
 
     
     # Attribute IsPassive uses Python identifier IsPassive
     __IsPassive = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'IsPassive'), 'IsPassive', '__urnoasisnamestcSAML2_0profilesSSOecp_RequestType_IsPassive', pyxb.binding.datatypes.boolean)
-    __IsPassive._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 38, 8)
-    __IsPassive._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 38, 8)
+    __IsPassive._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 38, 8)
+    __IsPassive._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 38, 8)
     
     IsPassive = property(__IsPassive.value, __IsPassive.set, None, None)
 
@@ -149,6 +152,7 @@ class RequestType (pyxb.binding.basis.complexTypeDefinition):
         __ProviderName.name() : __ProviderName,
         __IsPassive.name() : __IsPassive
     })
+_module_typeBindings.RequestType = RequestType
 Namespace.addCategoryObject('typeBinding', 'RequestType', RequestType)
 
 
@@ -159,31 +163,31 @@ class ResponseType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ResponseType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 42, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 42, 4)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Attribute {http://schemas.xmlsoap.org/soap/envelope/}mustUnderstand uses Python identifier mustUnderstand
     __mustUnderstand = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(_Namespace_S, 'mustUnderstand'), 'mustUnderstand', '__urnoasisnamestcSAML2_0profilesSSOecp_ResponseType_httpschemas_xmlsoap_orgsoapenvelopemustUnderstand', pyxb.bundles.wssplat.soap11.STD_ANON, required=True)
-    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/soap11.xsd', 75, 2)
-    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 43, 8)
+    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/soap11.xsd', 75, 2)
+    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 43, 8)
     
     mustUnderstand = property(__mustUnderstand.value, __mustUnderstand.set, None, None)
 
     
     # Attribute {http://schemas.xmlsoap.org/soap/envelope/}actor uses Python identifier actor
     __actor = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(_Namespace_S, 'actor'), 'actor', '__urnoasisnamestcSAML2_0profilesSSOecp_ResponseType_httpschemas_xmlsoap_orgsoapenvelopeactor', pyxb.binding.datatypes.anyURI, required=True)
-    __actor._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/soap11.xsd', 82, 2)
-    __actor._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 44, 8)
+    __actor._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/soap11.xsd', 82, 2)
+    __actor._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 44, 8)
     
     actor = property(__actor.value, __actor.set, None, None)
 
     
     # Attribute AssertionConsumerServiceURL uses Python identifier AssertionConsumerServiceURL
     __AssertionConsumerServiceURL = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'AssertionConsumerServiceURL'), 'AssertionConsumerServiceURL', '__urnoasisnamestcSAML2_0profilesSSOecp_ResponseType_AssertionConsumerServiceURL', pyxb.binding.datatypes.anyURI, required=True)
-    __AssertionConsumerServiceURL._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 45, 8)
-    __AssertionConsumerServiceURL._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 45, 8)
+    __AssertionConsumerServiceURL._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 45, 8)
+    __AssertionConsumerServiceURL._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 45, 8)
     
     AssertionConsumerServiceURL = property(__AssertionConsumerServiceURL.value, __AssertionConsumerServiceURL.set, None, None)
 
@@ -195,6 +199,7 @@ class ResponseType (pyxb.binding.basis.complexTypeDefinition):
         __actor.name() : __actor,
         __AssertionConsumerServiceURL.name() : __AssertionConsumerServiceURL
     })
+_module_typeBindings.ResponseType = ResponseType
 Namespace.addCategoryObject('typeBinding', 'ResponseType', ResponseType)
 
 
@@ -205,23 +210,23 @@ class RelayStateType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'RelayStateType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 49, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 49, 4)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.string
     
     # Attribute {http://schemas.xmlsoap.org/soap/envelope/}mustUnderstand uses Python identifier mustUnderstand
     __mustUnderstand = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(_Namespace_S, 'mustUnderstand'), 'mustUnderstand', '__urnoasisnamestcSAML2_0profilesSSOecp_RelayStateType_httpschemas_xmlsoap_orgsoapenvelopemustUnderstand', pyxb.bundles.wssplat.soap11.STD_ANON, required=True)
-    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/soap11.xsd', 75, 2)
-    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 52, 16)
+    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/soap11.xsd', 75, 2)
+    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 52, 16)
     
     mustUnderstand = property(__mustUnderstand.value, __mustUnderstand.set, None, None)
 
     
     # Attribute {http://schemas.xmlsoap.org/soap/envelope/}actor uses Python identifier actor
     __actor = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(_Namespace_S, 'actor'), 'actor', '__urnoasisnamestcSAML2_0profilesSSOecp_RelayStateType_httpschemas_xmlsoap_orgsoapenvelopeactor', pyxb.binding.datatypes.anyURI, required=True)
-    __actor._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/soap11.xsd', 82, 2)
-    __actor._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 53, 16)
+    __actor._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/soap11.xsd', 82, 2)
+    __actor._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 53, 16)
     
     actor = property(__actor.value, __actor.set, None, None)
 
@@ -232,23 +237,24 @@ class RelayStateType (pyxb.binding.basis.complexTypeDefinition):
         __mustUnderstand.name() : __mustUnderstand,
         __actor.name() : __actor
     })
+_module_typeBindings.RelayStateType = RelayStateType
 Namespace.addCategoryObject('typeBinding', 'RelayStateType', RelayStateType)
 
 
-Request = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Request'), RequestType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 29, 4))
+Request = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Request'), RequestType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 29, 4))
 Namespace.addCategoryObject('elementBinding', Request.name().localName(), Request)
 
-Response = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Response'), ResponseType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 41, 4))
+Response = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Response'), ResponseType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 41, 4))
 Namespace.addCategoryObject('elementBinding', Response.name().localName(), Response)
 
-RelayState = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'RelayState'), RelayStateType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 48, 4))
+RelayState = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'RelayState'), RelayStateType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 48, 4))
 Namespace.addCategoryObject('elementBinding', RelayState.name().localName(), RelayState)
 
 
 
-RequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(_Namespace_saml, 'Issuer'), pyxb.bundles.saml20.assertion.NameIDType, scope=RequestType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/assertion.xsd', 54, 4)))
+RequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(_Namespace_saml, 'Issuer'), pyxb.bundles.saml20.assertion.NameIDType, scope=RequestType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/assertion.xsd', 54, 4)))
 
-RequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(_Namespace_samlp, 'IDPList'), pyxb.bundles.saml20.protocol.IDPListType, scope=RequestType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/protocol.xsd', 188, 4)))
+RequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(_Namespace_samlp, 'IDPList'), pyxb.bundles.saml20.protocol.IDPListType, scope=RequestType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/protocol.xsd', 188, 4)))
 
 def _BuildAutomaton ():
     # Remove this helper function from the namespace after it is invoked
@@ -257,16 +263,16 @@ def _BuildAutomaton ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 33, 12))
+    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 33, 12))
     counters.add(cc_0)
     states = []
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(RequestType._UseForTag(pyxb.namespace.ExpandedName(_Namespace_saml, 'Issuer')), pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 32, 12))
+    symbol = pyxb.binding.content.ElementUse(RequestType._UseForTag(pyxb.namespace.ExpandedName(_Namespace_saml, 'Issuer')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 32, 12))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(RequestType._UseForTag(pyxb.namespace.ExpandedName(_Namespace_samlp, 'IDPList')), pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/saml20/schemas/ecp.xsd', 33, 12))
+    symbol = pyxb.binding.content.ElementUse(RequestType._UseForTag(pyxb.namespace.ExpandedName(_Namespace_samlp, 'IDPList')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/saml20/schemas/ecp.xsd', 33, 12))
     st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     transitions = []
