@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsrf_bf.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:1f695b8b0461ea6da4ae596208b164781fcb562b
-# Generated 2014-10-19 06:25:00.365913 by PyXB version 1.2.4 using Python 2.7.3.final.0
+# Generated 2016-09-18 17:34:09.356619 by PyXB version 1.2.5 using Python 2.7.12.final.0
 # Namespace http://docs.oasis-open.org/wsrf/bf-2
 
 from __future__ import unicode_literals
@@ -13,20 +13,23 @@ import pyxb.utils.utility
 import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
-
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9021dea0-5782-11e4-b82f-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:03f48ae0-7df0-11e6-9fa4-3497f68b2e96')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.4'
+_PyXBVersion = '1.2.5'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
 
+# A holder for module-level binding classes so we can access them from
+# inside class definitions where property names may conflict.
+_module_typeBindings = pyxb.utils.utility.Object()
+
 # Import bindings for namespaces imported into schema
-import pyxb.bundles.wssplat.wsa
-import pyxb.binding.datatypes
 import pyxb.binding.xml_
+import pyxb.binding.datatypes
+import pyxb.bundles.wssplat.wsa
 
 # NOTE: All namespace declarations are reserved within the binding
 Namespace = pyxb.namespace.NamespaceForURI('http://docs.oasis-open.org/wsrf/bf-2', create_if_missing=True)
@@ -82,41 +85,41 @@ class BaseFaultType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'BaseFaultType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 44, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 44, 2)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://docs.oasis-open.org/wsrf/bf-2}Timestamp uses Python identifier Timestamp
-    __Timestamp = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Timestamp'), 'Timestamp', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2Timestamp', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 48, 6), )
+    __Timestamp = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Timestamp'), 'Timestamp', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2Timestamp', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 48, 6), )
 
     
     Timestamp = property(__Timestamp.value, __Timestamp.set, None, None)
 
     
     # Element {http://docs.oasis-open.org/wsrf/bf-2}Originator uses Python identifier Originator
-    __Originator = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Originator'), 'Originator', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2Originator', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 50, 6), )
+    __Originator = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Originator'), 'Originator', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2Originator', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 50, 6), )
 
     
     Originator = property(__Originator.value, __Originator.set, None, None)
 
     
     # Element {http://docs.oasis-open.org/wsrf/bf-2}ErrorCode uses Python identifier ErrorCode
-    __ErrorCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'ErrorCode'), 'ErrorCode', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2ErrorCode', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 52, 6), )
+    __ErrorCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'ErrorCode'), 'ErrorCode', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2ErrorCode', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 52, 6), )
 
     
     ErrorCode = property(__ErrorCode.value, __ErrorCode.set, None, None)
 
     
     # Element {http://docs.oasis-open.org/wsrf/bf-2}Description uses Python identifier Description
-    __Description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Description'), 'Description', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2Description', True, pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 64, 6), )
+    __Description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Description'), 'Description', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2Description', True, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 64, 6), )
 
     
     Description = property(__Description.value, __Description.set, None, None)
 
     
     # Element {http://docs.oasis-open.org/wsrf/bf-2}FaultCause uses Python identifier FaultCause
-    __FaultCause = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'FaultCause'), 'FaultCause', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2FaultCause', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 74, 6), )
+    __FaultCause = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'FaultCause'), 'FaultCause', '__httpdocs_oasis_open_orgwsrfbf_2_BaseFaultType_httpdocs_oasis_open_orgwsrfbf_2FaultCause', False, pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 74, 6), )
 
     
     FaultCause = property(__FaultCause.value, __FaultCause.set, None, None)
@@ -133,6 +136,7 @@ class BaseFaultType (pyxb.binding.basis.complexTypeDefinition):
     _AttributeMap.update({
         
     })
+_module_typeBindings.BaseFaultType = BaseFaultType
 Namespace.addCategoryObject('typeBinding', 'BaseFaultType', BaseFaultType)
 
 
@@ -143,15 +147,15 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_MIXED
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 54, 8)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 54, 8)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Attribute dialect uses Python identifier dialect
     __dialect = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'dialect'), 'dialect', '__httpdocs_oasis_open_orgwsrfbf_2_CTD_ANON_dialect', pyxb.binding.datatypes.anyURI, required=True)
-    __dialect._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 57, 14)
-    __dialect._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 57, 14)
+    __dialect._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 57, 14)
+    __dialect._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 57, 14)
     
     dialect = property(__dialect.value, __dialect.set, None, None)
 
@@ -163,7 +167,7 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _AttributeMap.update({
         __dialect.name() : __dialect
     })
-
+_module_typeBindings.CTD_ANON = CTD_ANON
 
 
 # Complex type [anonymous] with content type SIMPLE
@@ -173,7 +177,7 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 66, 8)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 66, 8)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.string
@@ -181,7 +185,7 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
     # Attribute {http://www.w3.org/XML/1998/namespace}lang uses Python identifier lang
     __lang = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.XML, 'lang'), 'lang', '__httpdocs_oasis_open_orgwsrfbf_2_CTD_ANON__httpwww_w3_orgXML1998namespacelang', pyxb.binding.xml_.STD_ANON_lang)
     __lang._DeclarationLocation = None
-    __lang._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 69, 14)
+    __lang._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 69, 14)
     
     lang = property(__lang.value, __lang.set, None, None)
 
@@ -191,7 +195,7 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
     _AttributeMap.update({
         __lang.name() : __lang
     })
-
+_module_typeBindings.CTD_ANON_ = CTD_ANON_
 
 
 # Complex type [anonymous] with content type ELEMENT_ONLY
@@ -201,7 +205,7 @@ class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 75, 8)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 75, 8)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
@@ -212,23 +216,23 @@ class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
     _AttributeMap.update({
         
     })
+_module_typeBindings.CTD_ANON_2 = CTD_ANON_2
 
 
-
-BaseFault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BaseFault'), BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 42, 2))
+BaseFault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BaseFault'), BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 42, 2))
 Namespace.addCategoryObject('elementBinding', BaseFault.name().localName(), BaseFault)
 
 
 
-BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Timestamp'), pyxb.binding.datatypes.dateTime, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 48, 6)))
+BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Timestamp'), pyxb.binding.datatypes.dateTime, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 48, 6)))
 
-BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Originator'), pyxb.bundles.wssplat.wsa.EndpointReferenceType, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 50, 6)))
+BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Originator'), pyxb.bundles.wssplat.wsa.EndpointReferenceType, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 50, 6)))
 
-BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ErrorCode'), CTD_ANON, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 52, 6)))
+BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ErrorCode'), CTD_ANON, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 52, 6)))
 
-BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Description'), CTD_ANON_, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 64, 6)))
+BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Description'), CTD_ANON_, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 64, 6)))
 
-BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'FaultCause'), CTD_ANON_2, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 74, 6)))
+BaseFaultType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'FaultCause'), CTD_ANON_2, scope=BaseFaultType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 74, 6)))
 
 def _BuildAutomaton ():
     # Remove this helper function from the namespace after it is invoked
@@ -237,43 +241,43 @@ def _BuildAutomaton ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 46, 6))
+    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 46, 6))
     counters.add(cc_0)
-    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 50, 6))
+    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 50, 6))
     counters.add(cc_1)
-    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 52, 6))
+    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 52, 6))
     counters.add(cc_2)
-    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 64, 6))
+    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 64, 6))
     counters.add(cc_3)
-    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 74, 6))
+    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 74, 6))
     counters.add(cc_4)
     states = []
     final_update = None
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, 'http://docs.oasis-open.org/wsrf/bf-2')), pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 46, 6))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, 'http://docs.oasis-open.org/wsrf/bf-2')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 46, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Timestamp')), pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 48, 6))
+    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Timestamp')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 48, 6))
     st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_1, False))
-    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Originator')), pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 50, 6))
+    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Originator')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 50, 6))
     st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_2)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_2, False))
-    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'ErrorCode')), pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 52, 6))
+    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'ErrorCode')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 52, 6))
     st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_3)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_3, False))
-    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Description')), pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 64, 6))
+    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Description')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 64, 6))
     st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_4)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_4, False))
-    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'FaultCause')), pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 74, 6))
+    symbol = pyxb.binding.content.ElementUse(BaseFaultType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'FaultCause')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 74, 6))
     st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_5)
     transitions = []
@@ -333,11 +337,11 @@ def _BuildAutomaton_ ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 54, 8))
+    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 54, 8))
     counters.add(cc_0)
     cc_1 = fac.CounterCondition(min=0, max=None, metadata=None)
     counters.add(cc_1)
-    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 54, 8))
+    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 54, 8))
     counters.add(cc_2)
     states = []
     final_update = set()
@@ -368,7 +372,7 @@ def _BuildAutomaton_2 ():
     counters = set()
     states = []
     final_update = set()
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, 'http://docs.oasis-open.org/wsrf/bf-2')), pyxb.utils.utility.Location('/tmp/pyxbdist.mqXn05k/PyXB-1.2.4/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 77, 12))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, 'http://docs.oasis-open.org/wsrf/bf-2')), pyxb.utils.utility.Location('/tmp/pyxbdist.mjW1MNk/PyXB-1.2.5/pyxb/bundles/wssplat/schemas/wsrf_bf.xsd', 77, 12))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
