@@ -27,6 +27,14 @@ from pyxb.utils import six
 
 _log = logging.getLogger(__name__)
 
+class Object (object):
+    """A dummy class used to hold arbitrary attributes.
+
+    Essentially this gives us a map without having to worry about
+    converting names to text to use as keys.
+    """
+    pass
+
 def BackfillComparisons (cls):
     """Class decorator that fills in missing ordering methods.
 
@@ -180,6 +188,15 @@ def MakeIdentifier (s, camel_case=False):
         s = 'emptyString'
     return s
 
+def MakeModuleElement (s):
+    """Convert a string into something that can be a valid element in a
+    Python module path.
+
+    Module path elements are similar to identifiers, but may begin
+    with numbers and should not have leading underscores removed.
+    """
+    return _UnderscoreSubstitute_re.sub('_', _XMLIdentifierToPython(s))
+
 _PythonKeywords = frozenset( (
         "and", "as", "assert", "break", "class", "continue", "def", "del",
         "elif", "else", "except", "exec", "finally", "for", "from", "global",
@@ -696,8 +713,6 @@ def NormalizeLocation (uri, parent_uri=None, prefix_map=None):
     if parent_uri is None:
         abs_uri = uri
     else:
-        #if (0 > parent_uri.find(':')) and (not parent_uri.endswith(os.sep)):
-        #    parent_uri = parent_uri + os.sep
         abs_uri = urlparse.urljoin(parent_uri, uri)
     if prefix_map is None:
         prefix_map = LocationPrefixRewriteMap_
@@ -748,7 +763,7 @@ def DataFromURI (uri, archive_directory=None):
     try:
         # Protect this in case whatever stream is doesn't have an fp
         # attribute.
-        if isinstance(stream, six.file) or isinstance(stream.fp, six.file):
+        if isinstance(stream, six.moves.file) or isinstance(stream.fp, six.moves.file):
             archive_directory = None
     except:
         pass
@@ -1207,7 +1222,7 @@ class Location (object):
 
     def __init__ (self, location_base=None, line_number=None, column_number=None):
         if isinstance(location_base, str):
-            location_base = six.intern(location_base)
+            location_base = six.moves.intern(location_base)
         self.__locationBase = location_base
         self.__lineNumber = line_number
         self.__columnNumber = column_number
